==> ec2init-0.11-py3-none-any.whl: ec2init/plans/multinode/worker_seds.py <==
from ec2init.utils.backup_information import BackupInformation
import logging
import configparser

from pathlib import Path
from typing import List

from ec2init import Procedure
from ec2init.plans.multinode.seds import Seds
from ec2init.utils.system import SystemUtils
from ec2init.utils.cloud import get_cloud_provider

logger = logging.getLogger(__name__)

class WorkerSeds(Seds):
    def __init__(self, name: str, config: configparser.ConfigParser, check_file: Path, master_ip: str, cloud_provider: str, search_domain: str, node_id: str) -> None:
        super().__init__(name, config, cloud_provider, search_domain, node_id)
        self.check_file = check_file
        self.master_ip = master_ip

    def execute(self) -> List[Procedure]:
        logger.info("%s - Starting execution", self.name)
        children_proc: List[Procedure] = []
        super_procedures = super().execute()
        children_proc = super_procedures + children_proc

        #dig add a dot at the end of the fqdn the -1 is to remove it
        master_fqdn = SystemUtils.execute_command(["dig", "-x", self.master_ip, "+short"]).stdout.strip().decode("utf-8").replace('"','')[:-1]
        master_fqdn = get_cloud_provider(self.cloud_provider).select_dns_name(master_fqdn, self.search_domain)
        self.sed_almost_similar(self.master_ip, master_fqdn)
        #this is not a problem for backup because the worker are stateless and rebuilt from the base image after backup
        subString = "s/{0}/{1}/g".format(Seds.MASTER_IP, self.master_ip)
        cmd = Seds.REPLACE.format(subString, '/srv/hops/consul/consul.d/consul.hcl')
        logger.debug("%s - Adding %s retry join of consul.hcl", self.name, self.master_ip)
        SystemUtils.execute_command(cmd.split(" "))
        logger.info("%s - Replaced retry join of consul.hcl", self.name)

        if self.check_file:
            self.check_file.touch()

        return children_proc

==> ec2init-0.19.2-py3-none-any.whl: ec2init/plans/multinode/worker_seds.py <==
import logging
import configparser

from pathlib import Path
from typing import List

from ec2init import Procedure
from ec2init.plans.multinode.seds import Seds
from ec2init.utils.hopsfs import HopsFSUtils
from ec2init.utils.system import SystemUtils
from ec2init.utils.cloud import get_cloud_provider

logger = logging.getLogger(__name__)

class WorkerSeds(Seds):
    def __init__(self, name: str, config: configparser.ConfigParser, check_file: Path, master_ip: str, cloud_provider: str, search_domain: str, node_id: str, gateway: str, uid: str, instance_id: str, api_key: str) -> None:
        super().__init__(name, config, cloud_provider, search_domain, node_id, gateway, uid, instance_id, api_key)
        self.check_file = check_file
        self.master_ip = master_ip

    def execute(self) -> List[Procedure]:
        logger.info("%s - Starting execution", self.name)
        children_proc: List[Procedure] = []
        super_procedures = super().execute()
        children_proc = super_procedures + children_proc

        #dig add a dot at the end of the fqdn the -1 is to remove it
        master_fqdn = SystemUtils.execute_command(["dig", "-x", self.master_ip, "+short"]).stdout.strip().decode("utf-8").replace('"','')[:-1]
        master_fqdn = get_cloud_provider(self.cloud_provider).select_dns_name(master_fqdn, self.search_domain)
        self.sed_almost_similar(self.master_ip, master_fqdn)
        #this is not a problem for backup because the worker are stateless and rebuilt from the base image after backup
        subString = "s/{0}/{1}/g".format(Seds.MASTER_IP, self.master_ip)
        cmd = Seds.REPLACE.format(subString, '/srv/hops/consul/consul.d/consul.hcl')
        logger.debug("%s - Adding %s retry join of consul.hcl", self.name, self.master_ip)
        SystemUtils.execute_command(cmd.split(" "))
        logger.info("%s - Replaced retry join of consul.hcl", self.name)
        
        if self.check_file:
            self.check_file.touch()

        return children_proc
